@@ -12,7 +12,7 @@ Provides logging to syslog()
     use Sys::Syslog;
 
     # Get a new logger
-    my $log = Log::Fine->logger("foo");
+    my $log = Log::Fine->getLogger("foo");
 
     # register a syslog handle
     my $handle = Log::Fine::Handle::Syslog
@@ -45,7 +45,7 @@ use base qw( Log::Fine::Handle );
 
 use File::Basename;
 use Log::Fine;
-use Sys::Syslog 0.13 qw( :standard :macros );
+use Sys::Syslog qw( :standard :macros );
 
 # Constant: LOG_MAPPING
 #
@@ -66,9 +66,9 @@ use constant LOG_MAPPING => {
 
 =head1 METHODS
 
-=head2 msgWrite
+=head2 msgWrite($lvl, $msg, $skip)
 
-See L<Log::Fine::Handle/msgWrite>
+See L<Log::Fine::Handle>
 
 Note that this method B<does not> make use of a formatter as this is
 handled by the syslog facility.
@@ -114,7 +114,7 @@ sub _init
 
         # set the default facility
         $self->{facility} = LOG_LOCAL0
-            unless (defined $self->{facility}
+            unless (defined $self->{faciity}
                     and $self->{facility} =~ /\w+/);
 
         # open the syslog connection
@@ -176,11 +176,11 @@ L<http://search.cpan.org/dist/Log-Fine>
 
 =head1 REVISION INFORMATION
 
-  $Id: f8b8216e82a1923f993f047db480884f2ccad4ff $
+  $Id: Syslog.pm 76 2008-06-06 16:36:28Z cfuhrman $
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright (c) 2008, 2010 Christopher M. Fuhrman, 
+Copyright (c) 2008 Christopher M. Fuhrman, 
 All rights reserved.
 
 This program is free software licensed under the...
